==> kdesdk-3.0.1-i386-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libcatalogmanager.so )
( cd opt/kde/lib ; ln -sf libcatalogmanager.so.1.0.0 libcatalogmanager.so )
( cd opt/kde/lib ; rm -rf libcatalogmanager.so.1 )
( cd opt/kde/lib ; ln -sf libcatalogmanager.so.1.0.0 libcatalogmanager.so.1 )
( cd opt/kde/lib ; rm -rf libcervisia.so )
( cd opt/kde/lib ; ln -sf libcervisia.so.1.0.0 libcervisia.so )
( cd opt/kde/lib ; rm -rf libcervisia.so.1 )
( cd opt/kde/lib ; ln -sf libcervisia.so.1.0.0 libcervisia.so.1 )
( cd opt/kde/lib ; rm -rf libkbabel.so )
( cd opt/kde/lib ; ln -sf libkbabel.so.1.0.0 libkbabel.so )
( cd opt/kde/lib ; rm -rf libkbabel.so.1 )
( cd opt/kde/lib ; ln -sf libkbabel.so.1.0.0 libkbabel.so.1 )
( cd opt/kde/lib ; rm -rf libkbabelcommon.so )
( cd opt/kde/lib ; ln -sf libkbabelcommon.so.1.0.0 libkbabelcommon.so )
( cd opt/kde/lib ; rm -rf libkbabelcommon.so.1 )
( cd opt/kde/lib ; ln -sf libkbabelcommon.so.1.0.0 libkbabelcommon.so.1 )
( cd opt/kde/lib ; rm -rf libkbabeldict.so )
( cd opt/kde/lib ; ln -sf libkbabeldict.so.1.0.0 libkbabeldict.so )
( cd opt/kde/lib ; rm -rf libkbabeldict.so.1 )
( cd opt/kde/lib ; ln -sf libkbabeldict.so.1.0.0 libkbabeldict.so.1 )
( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so )
( cd opt/kde/lib ; ln -sf libkbabeldictplugin.so.1.0.0 libkbabeldictplugin.so )
( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so.1 )
( cd opt/kde/lib ; ln -sf libkbabeldictplugin.so.1.0.0 libkbabeldictplugin.so.1 )
( cd opt/kde/lib ; rm -rf libkspy.so )
( cd opt/kde/lib ; ln -sf libkspy.so.1.0.0 libkspy.so )
( cd opt/kde/lib ; rm -rf libkspy.so.1 )
( cd opt/kde/lib ; ln -sf libkspy.so.1.0.0 libkspy.so.1 )
( cd opt/kde/lib ; rm -rf libktrace.so )
( cd opt/kde/lib ; ln -sf libktrace.so.1.0.0 libktrace.so )
( cd opt/kde/lib ; rm -rf libktrace.so.1 )
( cd opt/kde/lib ; ln -sf libktrace.so.1.0.0 libktrace.so.1 )
( cd opt/kde/share/doc/HTML/en/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/cervisia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbabel ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> kdesdk-3.1-i386-2.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkbabeldict.so )
( cd opt/kde/lib ; ln -sf libkbabeldict.so.1.0.0 libkbabeldict.so )
( cd opt/kde/lib ; rm -rf libkbabelcommon.so )
( cd opt/kde/lib ; ln -sf libkbabelcommon.so.1.0.0 libkbabelcommon.so )
( cd opt/kde/lib ; rm -rf libkspy.so.1 )
( cd opt/kde/lib ; ln -sf libkspy.so.1.0.0 libkspy.so.1 )
( cd opt/kde/lib ; rm -rf libkbabel.so.1 )
( cd opt/kde/lib ; ln -sf libkbabel.so.1.0.0 libkbabel.so.1 )
( cd opt/kde/lib ; rm -rf libcatalogmanager.so.1 )
( cd opt/kde/lib ; ln -sf libcatalogmanager.so.1.0.0 libcatalogmanager.so.1 )
( cd opt/kde/lib ; rm -rf libkbabel.so )
( cd opt/kde/lib ; ln -sf libkbabel.so.1.0.0 libkbabel.so )
( cd opt/kde/lib ; rm -rf libktrace.so.1 )
( cd opt/kde/lib ; ln -sf libktrace.so.1.0.0 libktrace.so.1 )
( cd opt/kde/lib ; rm -rf libcervisia.so )
( cd opt/kde/lib ; ln -sf libcervisia.so.1.0.0 libcervisia.so )
( cd opt/kde/lib ; rm -rf libkbabeldict.so.1 )
( cd opt/kde/lib ; ln -sf libkbabeldict.so.1.0.0 libkbabeldict.so.1 )
( cd opt/kde/lib ; rm -rf libktrace.so )
( cd opt/kde/lib ; ln -sf libktrace.so.1.0.0 libktrace.so )
( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so )
( cd opt/kde/lib ; ln -sf libkbabeldictplugin.so.1.0.0 libkbabeldictplugin.so )
( cd opt/kde/lib ; rm -rf libkbabeldictplugin.so.1 )
( cd opt/kde/lib ; ln -sf libkbabeldictplugin.so.1.0.0 libkbabeldictplugin.so.1 )
( cd opt/kde/lib ; rm -rf libkbabelcommon.so.1 )
( cd opt/kde/lib ; ln -sf libkbabelcommon.so.1.0.0 libkbabelcommon.so.1 )
( cd opt/kde/lib ; rm -rf libcatalogmanager.so )
( cd opt/kde/lib ; ln -sf libcatalogmanager.so.1.0.0 libcatalogmanager.so )
( cd opt/kde/lib ; rm -rf libcervisia.so.1 )
( cd opt/kde/lib ; ln -sf libcervisia.so.1.0.0 libcervisia.so.1 )
( cd opt/kde/lib ; rm -rf libkspy.so )
( cd opt/kde/lib ; ln -sf libkspy.so.1.0.0 libkspy.so )
( cd opt/kde/share/doc/HTML/en/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/cervisia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kompare ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbabel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
